.c-wagtailautocomplete__sr-only{position:absolute;left:-10000px;top:auto;width:1px;height:1px;overflow:hidden}.c-wagtailautocomplete__layout{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between}.c-wagtailautocomplete__layout__item{width:49%}.c-wagtailautocomplete__selection{background-color:#ff7e77;color:#000;font-size:1.2em;border-radius:6px;margin-bottom:1em;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-webkit-align-items:center;-ms-flex-align:center;align-items:center}.c-wagtailautocomplete__selection--single,.c-wagtailautocomplete__selection:last-child{margin-bottom:0}.c-wagtailautocomplete__selection__button,.c-wagtailautocomplete__selection__label{padding:.9em 1.2em}.c-wagtailautocomplete__selection__button{background-color:transparent;border:0}.c-wagtailautocomplete__selection__icon{width:1.2em;height:1.2em}.c-wagtailautocomplete__selection__icon path{fill:#000}.c-wagtailautocomplete__suggestions{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;border-bottom-left-radius:6px;border-bottom-right-radius:6px;overflow-y:scroll;max-height:30vh}.c-wagtailautocomplete__suggestions::-webkit-scrollbar,.c-wagtailautocomplete__suggestions::-webkit-scrollbar-track{border-bottom-right-radius:6px}.c-wagtailautocomplete__suggestions::-webkit-scrollbar-track{background-color:#fff}.c-wagtailautocomplete__suggestions--populated,.c-wagtailautocomplete__suggestions__item{border:1px solid #e6e6e6;border-top-width:0}.c-wagtailautocomplete__suggestions__item{cursor:pointer;border-left-width:0;border-right-width:0;font-size:1.2em;padding:.9em .6em;background-color:#fff;z-index:1000;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-webkit-align-items:center;-ms-flex-align:center;align-items:center}.c-wagtailautocomplete__suggestions__item:last-child{border-bottom-width:0}.c-wagtailautocomplete__suggestions__item svg{width:1.2em;height:1.2em;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0}.c-wagtailautocomplete__suggestions__item path{fill:#fff}.c-wagtailautocomplete__suggestions__item--active{background-color:#ff7e77;color:#000}.c-wagtailautocomplete__suggestions__item--active path{fill:#000}input.c-wagtailautocomplete__search{padding-left:44px}input.c-wagtailautocomplete__search--has-input{border-bottom-left-radius:0;border-bottom-right-radius:0}div.c-wagtailautocomplete__search-input-container{position:relative}svg.c-wagtailautocomplete__search-icon{position:absolute;z-index:2;left:4px;top:7px;height:36px;width:36px;color:#9d9fa0}