<span
    data-autocomplete-input-name="{{ widget.name }}"
    data-autocomplete-input-value="{{ widget.value }}"
    data-autocomplete-input-type="{{ widget.target_model }}"
    data-autocomplete-input-id="{{ widget.attrs.id }}"
    {% if widget.can_create %}
        data-autocomplete-input-can-create
    {% endif %}
    {% if widget.is_single %}
        data-autocomplete-input-is-single
    {% endif %}
    data-autocomplete-input
></span>
